@@ -3,23 +3,13 @@ import shutil
 import unittest
 
 import yaml
-from bluesky.simulators import summarize_plan
 from pkg_resources import resource_filename as rs_fn
-
-import xpdacq.beamtime as xbt
-from xpdacq.beamtime import (
-    ScanPlan,
-    ct,
-    Beamtime,
-    Sample,
-)
+from xpdacq.beamtime import Beamtime, Sample, ScanPlan, ct
 from xpdacq.beamtimeSetup import _start_beamtime, load_beamtime
 from xpdacq.glbl import glbl
-from xpdacq.simulation import pe1c, db, shctl1, cs700, fb
+from xpdacq.simulation import cs700, db, fb, pe1c, shctl1
 from xpdacq.xpdacq import CustomizedRunEngine
 from xpdacq.xpdacq_conf import configure_device
-from xpdacq.xpdacq_conf import xpd_configuration
-
 
 # print messages for debugging
 # xrun.msg_hook = print
@@ -74,14 +64,6 @@ class BeamtimeObjTest(unittest.TestCase):
         if os.path.isdir(os.path.join(self.base_dir, "pe2_data")):
             shutil.rmtree(os.path.join(self.base_dir, "pe2_data"))
 
-    def test_print_scanplan(self):
-        # using positional args
-        sp1 = ScanPlan(self.bt, ct, 1)
-        # using kwargs is equivalent
-        sp2 = ScanPlan(self.bt, ct, exposure=1)
-        # test Msg processed
-        self.assertEqual(str(sp1), str(sp2))
-
     def test_ct_scanplan_autoname(self):
         sp = ScanPlan(self.bt, ct, 1)
         # std_f_name = 'ct_1_None.yml' #py3.4 only gets args
@@ -277,13 +259,3 @@ class BeamtimeObjTest(unittest.TestCase):
         glbl["frame_acq_time"] = 0.5
         self.assertRaises(ValueError, lambda: xrun({}, ScanPlan(bt, ct, 0.2)))
         glbl["frame_acq_time"] = 0.1  # reset after test
-
-
-def test_count_with_calib():
-    if "shutter" not in xpd_configuration:
-        xpd_configuration["shutter"] = shctl1
-    poni_file = rs_fn("xpdacq", "tests/Ni_poni_file.poni")
-    md = xbt.load_calibration_md(poni_file)
-    print(md)
-    plan = xbt.count_with_calib([pe1c], num=2, delay=3, calibration_md=md)
-    summarize_plan(plan)
